==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Kliknij aby uzyskać dostęp do tego urządzenia w innych aplikacjach.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>Kliknij aby wysunąć ten dysk.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="185"/>
        <source>Removable media/devices manager</source>
        <translation>Menedżer urządzeń</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="278"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Urządzenie &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest podłączone.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="297"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Urządzenie &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest odłączone.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="340"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>Urządzenie &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest zamontowane w %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="354"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>Urządzenie &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest odmontowane&lt;br&gt;
Teraz możesz wysunąć pamięć flash albo dysk CD/DVD.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="386"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>Nie mogę zamontować urządzenia: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="392"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>Urządzenie &apos;%1&apos; zostało zamontowane w %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="419"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>Nie mogę odmontować urządzenia: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="423"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>Urządzenie &apos;%1&apos; jest odmontowane</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="439"/>
        <source>No devices Available.</source>
        <translation>Brak urządzeń.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Ustawienia Menedżera urządzeń</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Kiedy nowe urządzenie jest podłączane</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>Pokaż listę</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Show info</source>
        <translation>Pokaż informację</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Do nothing</source>
        <translation>Nic nierób</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Kliknij aby uzyskać dostęp do tego nośnika z innych aplikacji.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Kliknij aby wysunąć ten dysk.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Menedżer nośników wymiennych</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Nośnik &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest podłączony.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Nośnik &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; jest odłączony.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>Brak urządzeń</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Ustawienia menedżera nośników wymiennych</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Kiedy nośnik jest podłączony</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Pokaż listę</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Pokaż informacje</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nic nierób</translation>
    </message>
</context>
</TS>
